package com.ruoyi.rocketmq.service;

import com.ruoyi.rocketmq.domain.InitialSwitchMpuInfo;

import java.util.List;
import java.util.Map;

/**
 * MPU信息Service接口
 * 
 * @author gyt
 * @date 2025-09-22
 */
public interface IInitialSwitchMpuInfoService 
{
    /**
     * 查询MPU信息
     * 
     * @param id MPU信息主键
     * @return MPU信息
     */
    public InitialSwitchMpuInfo selectInitialSwitchMpuInfoById(Long id);

    /**
     * 查询MPU信息列表
     * 
     * @param initialSwitchMpuInfo MPU信息
     * @return MPU信息集合
     */
    public List<InitialSwitchMpuInfo> selectInitialSwitchMpuInfoList(InitialSwitchMpuInfo initialSwitchMpuInfo);

    /**
     * 新增MPU信息
     * 
     * @param initialSwitchMpuInfo MPU信息
     * @return 结果
     */
    public int insertInitialSwitchMpuInfo(InitialSwitchMpuInfo initialSwitchMpuInfo);

    /**
     * 修改MPU信息
     * 
     * @param initialSwitchMpuInfo MPU信息
     * @return 结果
     */
    public int updateInitialSwitchMpuInfo(InitialSwitchMpuInfo initialSwitchMpuInfo);

    /**
     * 批量删除MPU信息
     * 
     * @param ids 需要删除的MPU信息主键集合
     * @return 结果
     */
    public int deleteInitialSwitchMpuInfoByIds(Long[] ids);

    /**
     * 删除MPU信息信息
     * 
     * @param id MPU信息主键
     * @return 结果
     */
    public int deleteInitialSwitchMpuInfoById(Long id);

    /**
     * 批量新增mpu信息
     * @param list
     * @return
     */
    public int insertBatchInitialSwitchMpuInfo(List<InitialSwitchMpuInfo> list);

    /**
     * 获取该交换机所有mpu名称
     * @param initialSwitchMpuInfo
     * @return
     */
    List<Map> getAllMpuName(InitialSwitchMpuInfo initialSwitchMpuInfo);

    /**
     * mpu基础信息
     * @param initialSwitchMpuInfo
     * @return
     */
    List<InitialSwitchMpuInfo> getMpuMsg(InitialSwitchMpuInfo initialSwitchMpuInfo);

    /**
     * mpu的cpu使用率
     * @param initialSwitchMpuInfo
     * @return
     */
    Map<String, Object> getMpuCpuUse(InitialSwitchMpuInfo initialSwitchMpuInfo);

    /**
     * mpu的内存使用率
     * @param initialSwitchMpuInfo
     * @return
     */
    Map<String, Object> getMpuMemUse(InitialSwitchMpuInfo initialSwitchMpuInfo);

    /**
     * mpu的温度
     * @param initialSwitchMpuInfo
     * @return
     */
    Map<String, Object> getMpuTemperature(InitialSwitchMpuInfo initialSwitchMpuInfo);
}
